@@ -25,10 +25,21 @@ try:
 except ImportError:
     inkscape_env = False # Keep on trucking without an env
 
+
 import os
 import sys
 import logging
 
+try:
+    import gtkme
+except ModuleNotFoundError as err:
+    if err.name in ['gi']:
+        sys.stderr.write("Your computer does not have PyGObject, this should have been shipped with Inkscape. Please report this as a bug and make sure to specify your operating system below:\n")
+        import platform
+        my_os = platform.platform() + " " + platform.version()
+        sys.stderr.write(f"\nOS: {my_os}\n\n")
+        sys.exit(1)
+
 from argparse import ArgumentParser
 
 # The pinned version of pip has warnings for python 3.8
